#
# spec file for package zathura
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           zathura
Version:        0.5.8
Release:        1.2
Summary:        A customizable document viewer
License:        Zlib
URL:            https://pwmt.org/projects/zathura/
Source:         %{url}/download/%{name}-%{version}.tar.xz
# PATCH-FIX-OPENSUSE no-parallel-xvfb.patch smolsheep@opensuse.org -- Fix tests that rely on xvfb
Patch0:         no-parallel-xvfb.patch
BuildRequires:  appstream-glib
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  file-devel
BuildRequires:  fish
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  python3-Sphinx
BuildRequires:  rsvg-convert
BuildRequires:  xvfb-run
BuildRequires:  zsh
BuildRequires:  pkgconfig(check)
BuildRequires:  pkgconfig(girara-gtk3) >= 0.4.3
BuildRequires:  pkgconfig(libseccomp)
BuildRequires:  pkgconfig(sqlite3)
Recommends:     %{name}-lang
Recommends:     zathura-pdf-poppler-plugin
Suggests:       zathura-cb-plugin
Suggests:       zathura-djvu-plugin
Suggests:       zathura-ps-plugin
%if 0%{?suse_version} >= 1550
BuildRequires:  pkgconfig(synctex) >= 1.19
%endif

%description
zathura is a customizable document viewer. It provides a minimalistic
and space-saving interface as well as a keyboard-centric interaction.

%package devel
Summary:        Development files for zathura
Requires:       %{name} = %{version}

%description devel
Development and header files for the zathura package.

%package bash-completion
Summary:        Zathura Bash completion
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)

%description bash-completion
Optional dependency offering bash completion for zathura

%package zsh-completion
Summary:        Zathura zsh completion
Requires:       %{name} = %{version}
Requires:       zsh
Supplements:    (%{name} and zsh)

%description zsh-completion
Optional dependency offering zsh completion for zathura

%package fish-completion
Summary:        Zathura fish completion
Requires:       %{name} = %{version}
Requires:       fish
Supplements:    (%{name} and fish)

%description fish-completion
Optional dependency offering fish completion for zathura

%lang_package

%prep
%autosetup -p1

%build
export CFLAGS="%{optflags}"
%if 0%{?suse_version} < 1550
%meson -Dsynctex=disabled
%else
%meson
%endif
%meson_build

%check
%if 0%{?qemu_user_space_build}
# qemu does not implement seccomp
echo 'int main() { return 77; }' > tests/test_session.c
%endif
%meson_test

%install
%meson_install
%find_lang %{name} %{?no_lang_C}

%files
%license LICENSE
%doc README.md AUTHORS
%{_bindir}/%{name}
%{_bindir}/%{name}-sandbox
%{_datadir}/dbus-1/interfaces/org.pwmt.%{name}.xml
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_mandir}/man1/%{name}-sandbox.1%{?ext_man}
%{_mandir}/man5/%{name}rc.5%{?ext_man}
%{_datadir}/applications/org.pwmt.zathura.desktop
%{_datadir}/icons/hicolor/*/apps/org.pwmt.zathura.*
%{_datadir}/metainfo/org.pwmt.zathura.appdata.xml

%files devel
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/*.h
%{_libdir}/pkgconfig/%{name}.pc

%files bash-completion
%{_datadir}/bash-completion/completions/zathura

%files zsh-completion
%{_datadir}/zsh/site-functions/_zathura

%files fish-completion
%{_datadir}/fish/vendor_completions.d/zathura.fish

%files lang -f %{name}.lang

%changelog
* Tue Aug  6 2024 Jan Kužílek <jan.kuzilek@suse.com>
- Update no-parallel-xvfb.patch to current version
- Update to 0.5.8:
  * Bump plugin ABI
- Update to 0.5.7:
  * Split sandbox functionality into separate zathura-sandbox binary
  * Split off new command bjump from blist
  * Add initial landlock support to sandbox
  * Fix repeated search
  * Implement jumplist command
  * Fix issues with document with multiple page sizes
  * Various fixes and improvements
* Thu Jun 13 2024 Joshua Smith <smolsheep@opensuse.org>
- Update no-parallel-xvfb.patch to current version
- Migrate from deprecated setup to autosetup
- Update to 0.5.6:
  * Move to Github
  * Reduce minimum glib version
  * Remove normal sandbox mode
  * Various fixes and improvements
- Updates from 0.5.5:
  * Compatibility with girara 0.4.3
  * Remove highlight-transparency setting. Set the alpha component
    of highlight-color, highlight-active-color and highlight-fg
    instead.
  * Remove smooth-reload setting. Smooth reloading is now always
    enabled.
  * Remove plain database backend. The sqlite database backend
    imports the data from the plain database the first time. sqlite
    is now a hard dependency.
  * Fix a segfault if dbus is not enabled.
* Wed Feb 21 2024 Andreas Schwab <schwab@suse.de>
- Skip test_session in qemu emulation
* Sun Dec 31 2023 Joshua Smith <jsmithfpv@gmail.com>
- update to 0.5.4:
  * Various fixes and improvements
- added no-parallel-xvfb.patch from ALT
* Wed Dec  7 2022 Dirk Müller <dmueller@suse.com>
- update to 0.5.2:
  * Improve text selection
  * Various fixes and improvements
  * Updated translations
* Mon Sep 19 2022 Ondřej Súkup <mimi.vx@gmail.com>
- update to 0.5.1
  * seccomp: Make glibc fallback to clone instead of using clone3
  * magic is now a required dependency
  * Various fixes and improvements
* Thu Feb 24 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to 0.4.9
  * Add '$f' and '$p' expansions to 'exec' shortcut function
  * Fix build with meson 0.60
  * Add :source command
  * Various fixes and improvements
  * Updated translations
- Update tarball url.
* Wed Aug  4 2021 Paolo Stivanin <info@paolostivanin.com>
- update to 0.4.8
  * Account for page padding in full scroll
  * Add forefground color for links
  * Add :save and :save! aliases for :write and :write!
  * Various fixes and improvements
  * Updated translations
* Wed Sep 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.4.7
  * bugfixes
  * translations update
* Tue Feb 11 2020 Ondřej Súkup <mimi.vx@gmail.com>
- update to 0.4.5
  * bugfixes
  * translations update
* Tue Nov  5 2019 Ondřej Súkup <mimi.vx@gmail.com>
- update to 0.4.4
  * Various fixes
  * better location for zsh completion
  * new fish completion
* Wed Oct 23 2019 ro@suse.de
- fix build-requires for factory/tumbleweed
  rsvg-convert tool is now in rsvg-convert package
* Fri Apr 26 2019 Xaver Hellauer <xaver@hellauer.bayern>
- Resolve shell completion via "Supplements:", i.e. bash/zsh completion are recommends if and only if the shells are installed as well.
* Mon Feb  4 2019 Ondřej Súkup <mimi.vx@gmail.com>
- update to 0.4.3
  * Various fixes and improvements
  * Add bash and zsh completions
  * Add RTL layout of pages
* Wed Aug  8 2018 jengelh@inai.de
- Trim exaggerations from description.
* Wed May 23 2018 mimi.vx@gmail.com
- update to 0.4.0
  * move to meson build system
  * Port to newer libsynctex
  * Improved HiDPI support
  * Display page labels
* Fri Jan 26 2018 mimi.vx@gmail.com
- update to 0.3.8
  * Fix memory leaks
  * Rework plugin initialization
* Sun Feb  5 2017 mimi.vx@gmail.com
- update to 0.3.7
  * Improved logging
  * Improve page mode toggling
  * Several fixes and improvements
  * Updated translations
* Thu Jun  2 2016 mimi.vx@gmail.com
- update to 0.3.6
  * Parallel build of manpages
  * Several fixes and improvements
* Sun Mar 20 2016 mimi.vx@gmail.com
- added libsynctex support on openSUSE:Tumbleweed
* Tue Feb 23 2016 mimi.vx@gmail.com
- update to 0.3.5
  * Build even without SyncTex
  * Children should not fork
  * Recent files support
  * Substitute home with tilde
  * Open URLs
* Sun May 10 2015 mimi.vx@gmail.com
- update to 0.3.3
- Store tmp files in only one location
- Print target selection
- Fix dual page render breakage of adjust_window
- Update translations
- Update buld system
* Wed Nov 12 2014 mimi.vx@gmail.com
- Update to upstream version 0.3.2
- resolve memory leak while reloading file
- Prevent segmentation fault when smooth zooming with mouse
- Cache thumbnails to support smooth zooming
- Check scale value correctness
- Update build system
- Update translations
* Tue Oct 28 2014 mimi.vx@gmail.com
- change library Zlib
* Mon Oct 27 2014 tchvatal@suse.com
- Disable stripping.
* Fri Oct 24 2014 mimi.vx@gmail.com
- Bump to 0.3.1
- Segmentation fault caused by bidirectional scrolling
- Add SyntaxView
* Thu Oct 23 2014 mimi.vx@gmail.com
- remove unneed deps
* Thu Oct 23 2014 mimi.vx@gmail.com
- change make comand
- add one file
* Tue Oct 21 2014 mimi.vx@gmail.com
- change minimal version of giara
* Tue Oct 21 2014 mimi.vx@gmail.com
- change extension im man page
* Tue Oct 21 2014 mimi.vx@gmail.com
- updated  last upstream version 0.3.0
  - taken from home:AndnoVember:test
  - complete changelog http://pwmt.org/projects/zathura/changelog/
* Sat May 12 2012 seiler@b1-systems.de
- removed unneed autcommented lines
- added RPM Optflags to gcc CFLAGS
- removed duplicate file listing in %%files section
- added Variable $LIBDIR=%%{_libdir} to the make install command
- replaced update-desktop-database with macros
* Wed Apr 25 2012 seiler@b1-systems.de
- initial package/commit
